import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:scrollable_positioned_list/scrollable_positioned_list.dart';

class ViewPagerIndicator extends StatefulWidget{
  double _pagerHeight;
  double _borderRadius;
  double _indicatorPadding;
  Function _onCardClick;
  List<Widget> _cardWidget;
  ViewPagerIndicator(Function onCardClick,List<Widget> cardWidget,{double pagerHeight=200,double borderRadius=16,double indicatorPadding=4})
  {
    _pagerHeight=pagerHeight;
    _borderRadius=borderRadius;
    _indicatorPadding=indicatorPadding;
    _onCardClick=onCardClick;
    _cardWidget=cardWidget;
  }
  @override
  State<StatefulWidget> createState() {
    return ViewPagerIndicatorState();
  }
}
class ViewPagerIndicatorState extends State<ViewPagerIndicator>{
  PageController _pageController;
  int _currentPage=0;
  ItemScrollController _itemScrollController;
  @override
  void initState() {
    _pageController=new PageController(initialPage: _currentPage);
    _itemScrollController=new ItemScrollController();

    super.initState();
  }

  @override
  void didChangeDependencies() {
    _pageController.addListener(pager_listener);
    super.didChangeDependencies();
  }

  void pager_listener()
  {
    if(_currentPage!=_pageController.page.round())
    {
      setState(() {
        _currentPage=_pageController.page.round();
      });
      _itemScrollController.scrollTo(index: _currentPage, duration: Duration(seconds: 1),curve: Curves.easeOutCirc);
    }
  }

  @override
  Widget build(BuildContext context) {

    return Row(
      mainAxisSize: MainAxisSize.max,
      mainAxisAlignment: MainAxisAlignment.start,
      crossAxisAlignment: CrossAxisAlignment.center,
      children: [
        Expanded(
          flex: 9,
          child: ClipRRect(
            borderRadius: BorderRadius.all(Radius.circular(widget._borderRadius)),
            child: Container(
              height: widget._pagerHeight,
              child: PageView.builder(
                scrollDirection: Axis.vertical,
                controller: _pageController,
                physics: BouncingScrollPhysics(),
                itemBuilder: (context, position) {
                  return builder(position);
                },
                itemCount: widget._cardWidget.length,
              ),
            ),
          ),
        ),
        Expanded(
          flex: 1,
          child: Container(
            height: widget._pagerHeight/2,
            alignment: Alignment.center,
            child: ScrollablePositionedList.builder(
              itemScrollController: _itemScrollController,
              scrollDirection: Axis.vertical,
              //physics: FixedExtentScrollPhysics(),
              itemBuilder: (context,index)
              {
                return Container(
                  width: widget._indicatorPadding*1.5,
                  height: widget._indicatorPadding*1.5,
                  margin: EdgeInsets.all(widget._indicatorPadding),
                  decoration: BoxDecoration(
                    shape: BoxShape.circle,
                    color: index  == _currentPage ? Colors.white70 : Colors.grey,
                  ),
                );
              },
              itemCount: widget._cardWidget.length,
            ),
          ),
        ),
      ],
    );
  }

  builder(int index) {
    return AnimatedBuilder(
      animation: _pageController,
      builder: (context, child) {
        double value = 1.0;
        if (_pageController.position.haveDimensions) {
          value = _pageController.page - index;
          value = (1 - (value.abs() * .5)).clamp(0.0, 1.0);
        }
        return Center(
          child: SizedBox(
            height: Curves.easeOut.transform(value) * widget._pagerHeight,
            width: Curves.easeOut.transform(value) * (MediaQuery.of(context).size.width*0.9)-20,
            child: child,
          ),
        );
      },
      child: ClipRRect(
        borderRadius: BorderRadius.all(Radius.circular(widget._borderRadius)),
        clipBehavior: Clip.hardEdge,
        child: widget._cardWidget[index],
      ),
    );
  }

}